tpDcc-libs-nameit
============================================================

Tool that manages the nomenclature of your pipelines.

* Nomenclature is based on rules and tokens. Those can be setup in a per-project basis.
* DCC agnostic way, the library works in any DCC supported by tpDccLib

.. image:: https://travis-ci.com/tpDcc/tpDcc-libs-nameit.svg?branch=master&kill_cache=1
    :target: https://travis-ci.com/tpDcc/tpDcc-libs-nameit

.. image:: https://coveralls.io/repos/github/tpDcc/tpDcc-libs-nameit/badge.svg?branch=master&kill_cache=1
    :target: https://coveralls.io/github/tpDcc/tpDcc-libs-nameit?branch=master

.. image:: https://img.shields.io/badge/docs-sphinx-orange
    :target: https://tpDcc.github.io/tpDcc-libs-nameit

.. image:: https://img.shields.io/github/license/tpDcc/tpDcc-libs-nameit
    :target: https://github.com/tpDcc/tpDcc-libs-nameit/blob/master/LICENSE

.. image:: https://img.shields.io/pypi/v/tpDcc-libs-nameit?branch=master&kill_cache=1
    :target: https://pypi.org/project/tpDcc-libs-nameit

.. image:: https://img.shields.io/badge/code_style-pep8-blue
    :target: https://www.python.org/dev/peps/pep-0008/